| Title: | Lake geoid correction grids |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Karina Nielsen [aut, cre] (ORCID: <https://orcid.org/0000-0002-0035-1869>) |
| Maintainer: | Karina Nielsen <[email protected]> |
| License: | `use_mit_license()`, `use_gpl3_license()` or friends to pick a license |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-28 14:54:32 UTC |
| Source: | https://github.com/cavios/LakeGeoid |
The CryoSat-2 L1b waveforms were retracked by the Narrow Primary Peak retracker (Villadsen, H., Andersen, O.B., Stenseng, L., Nielsen, K. and Knudsen, P., 2015. CryoSat-2 altimetry for river level monitoring—Evaluation in the Ganges–Brahmaputra River basin. Remote Sensing of Environment, 168, pp.80-89.). CryoSat-2 is available from
L1b SAR Precise Orbit. Baseline E.https://doi.org/10.5270/CR2-fbae3cd
L1b LRM Precise Orbit, Baseline E.https://doi.org/10.5270/CR2-41ad749
L1b SARin Precise Orbit. Baseline E.https://doi.org/10.5270/CR2-6afef01
Karina Nielsen ([email protected])
Paper in prep
Predict the geoid correction error
getGeoidCorr(fit, newdat, UTM = TRUE)getGeoidCorr(fit, newdat, UTM = TRUE)
fit |
Object returned by getLakeGeoid() |
newdat |
a data set at least including the columns named "lon" and "lat" with the coordinates where the corretion should be predicted. |
UTM |
logic variable to indicate if the estimated field is in a UTM projection (FALSE means the field is in degrees) |
The function getLakeGeoid reconstruct a static spatial water level signal and a water level time series. The static spatial signal is modeled as a Gaussian Markov Random Field on a triangular mesh where the nodes specifies the neighbor structure. The water level time series is modeled with an Random Walk as the underlying process and the observation error is here assumed to be Gaussian. The Static spatial field is here intended to models potential missing geoid model signals.
getLakeGeoid(dat, maxEdge, myshape, UTM = TRUE)getLakeGeoid(dat, maxEdge, myshape, UTM = TRUE)
dat |
Input data set; must at least contain columns names: time (decimal years), lon (longitude in decimal degrees ), lat (latitude in decimal degrees), height (meters) |
maxEdge |
Maximum side length of the triangles in the mesh (created by the function "fm_mesh_2d" from the package "fmesher"). |
myshape |
a shapefile/polygon of the class "sf" defining the boundary of the lake where the model will be reconstructed. |
UTM |
logic variable to specify if the coordinates should be projected to UTM coordinates (the default is TRUE) |
Selected columns of the Level 2 Water Mask Raster Image 250m Data Product, Version C. The data has been filtered by "darkwater_frac", large outliers were removed, and the data has been down sampled to reduce the volume.
SWOT Level 2 Water Mask Raster Image 250m Data Product, Version C (10.5067/SWOT-RASTER-2.0)
Surface Water Ocean Topography (SWOT). 2024. SWOT Level 2 Water Mask Raster Image Data Product, Version C. Ver. C. PO.DAAC, CA, USA. Dataset accessed 2025-04-01 at https://doi.org/10.5067/SWOT-RASTER-2.0
A shapefile of the class "sf" for the African lake Kivu. The shapefile is taken from the SWOT Prior Lake Database.
Wang et al.
Wang, J., Pottier, C., Cazals, C., Battude, M., Sheng, Y., Song, C., Sikder, M.S., Yang, X., Ke, L., Gosset, M. and Oliveira, R.R.A., 2023. The Surface Water and Ocean Topography Mission (SWOT) Prior Lake Database (PLD): Lake mask and operational auxiliaries. Authorea Preprints.https://www.authorea.com/doi/full/10.22541/au.170258987.72387777
Plot an object returned by the function getLakeGeoid()
## S3 method for class 'LakeGeoid' plot(fit, zlim = NULL, dat = NULL, doSave = FALSE)## S3 method for class 'LakeGeoid' plot(fit, zlim = NULL, dat = NULL, doSave = FALSE)
fit |
Object returned by getLakeGeoid() |
zlim |
vector with the zlim interval c(low,high), defined by the field "omega" if not specified |
dat |
The raw water level data can be added to the plot |
doSave |
plot is saved to a pdf file |
plot(fit)plot(fit)
This function presents a summary of the output
## S3 method for class 'LakeGeoid' print(x)## S3 method for class 'LakeGeoid' print(x)
x |
An object of class "LakeGeoid" |
Print the objective function and state convergence
This function presents a summary of the output
## S3 method for class 'LakeGeoid' summary(x)## S3 method for class 'LakeGeoid' summary(x)
x |
An object of class "LakeGeoid" |
Summary of output